@@ -1,5 +1,6 @@
-__pacakge_name__ = 'gdal-utils'
-__version__ = '3.3.0.6'
+__package_name__ = 'gdal-utils'
+gdal_utils_version = (3, 3, 1, 0)
+__version__ = '.'.join(str(i) for i in gdal_utils_version)
 __author__ = "Frank Warmerdam"
 __author_email__ = "warmerdam@pobox.com"
 __maintainer__ = "Idan Miara"
